@@ -15,7 +15,7 @@ from . import (
     const,
 )
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 
 def md5sum(content):
@@ -47,3 +47,28 @@ def dirpath(path, depth=1):
     for i in range(depth):
         path = os.path.dirname(path)
     return path
+
+
+def _generate_parent_dir(fp_path, limit=1, subdir=".git"):
+    fn = os.path.abspath(fp_path)
+    if os.path.isdir(fn):
+        p = fn
+    else:
+        p = os.path.dirname(fn)
+    while limit:
+        p2 = os.path.join(p, subdir)
+        if os.path.isdir(p2):
+            limit -= 1
+            yield p
+        p3 = os.path.dirname(p)
+        if p3 == p:
+            limit = 0
+        else:
+            p = p3
+
+
+def get_parent_dir(fp_path, subdir=".git"):
+    _gen = _generate_parent_dir(fp_path, limit=1, subdir=subdir)
+    ps = list(_gen)
+    if len(ps) > 0:
+        return ps[0]
